# Библиотека для загрузки проектов на PyPI и TestPyPI

Библиотека способна быстро и просто выгрузить проекты. Проект доступен из командной строки.

```
uploadi [-h] [-t] [-p] name_project
```

1. **-h**: Выведет справочную информацию
2. **-t**: Проект будет выгружен на TestPyPI
3. **-p**: Проект будет выгружен на PyPI
4. **name_project**: название вашего проекта

## Пример
Эта команда выгрузит проект ipars на TestPyPI
```bash
uploadi -t ipars
```
Эта команда выгрузит проект requests на PyPI
```bash
uploadi -p requests
```
